# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.0-alpha.3](https://github.com/lox-space/lox/compare/lox-math-v0.1.0-alpha.2...lox-math-v0.1.0-alpha.3) - 2024-12-18

### Other

- fix clippy lints

## [0.1.0-alpha.2](https://github.com/lox-space/lox/compare/lox-math-v0.1.0-alpha.1...lox-math-v0.1.0-alpha.2) - 2024-11-12

### Other

- update Cargo.toml dependencies

## [0.1.0-alpha.1](https://github.com/lox-space/lox/compare/lox-math-v0.1.0-alpha.0...lox-math-v0.1.0-alpha.1) - 2024-07-19

### Other
- release ([#144](https://github.com/lox-space/lox/pull/144))

## [0.1.0-alpha.0](https://github.com/lox-space/lox/releases/tag/lox-math-v0.1.0-alpha.0) - 2024-07-19

### Other
- Rename lox-utils to lox-math because the former is taken ([#146](https://github.com/lox-space/lox/pull/146))
